@@ -25,8 +25,8 @@ setClass(
 
 setMethod(
   "initialize", "equation_basic",
-  function(.Object, quantity, price, specification, data, name, prefix) {
-    .Object <- callNextMethod(.Object, quantity, price, specification, data, name, prefix)
+  function(.Object, specification, data, name, prefix) {
+    .Object <- callNextMethod(.Object, specification, data, name, prefix)
     .Object
   }
 )
